@@ -108,19 +108,25 @@ class DynamoDB:
 
         return output
 
-    def dynamodb_update_item(self, key_fields, update_fields):
+    def dynamodb_update_item(self, key_fields, update_fields, start_key=None):
 
-        Key = awsUtils.dynamodb_format_json(key_fields)
+        Key = self.dynamodb_format_json(key_fields)
         Names = {}
+        if start_key:
+            rand_start = utils.randStr()
+            Names[f"#{rand_start}"] = start_key
         Values = {}
         Expression = "SET "
         for update_field in update_fields:
             random_str = utils.randStr()
-            x = awsUtils.dynamodb_format_json(update_field)
+            x = self.dynamodb_format_json(update_field)
             for y, z in x.items():
                 Names[f"#{random_str}"] = y
                 Values[f":{random_str}"] = z
-                Expression += f"#{random_str} = :{random_str}, "
+                if not start_key:
+                    Expression += f"#{random_str} = :{random_str}, "
+                else:
+                    Expression += f"#{rand_start}.#{rand_start} = :{random_str}, "
 
         Expression = Expression.rstrip(", ")
 
